@@ -1,7 +1,7 @@
 use strict;
 package CPAN::Reporter::Config;
 
-our $VERSION = '1.2018';
+our $VERSION = '1.2020';
 
 use Config::Tiny 2.08 ();
 use File::Glob ();
@@ -154,7 +154,7 @@ sub _configure {
     $CPAN::Frontend->myprint(
         "\nCPAN::Reporter: writing config file to '$config_file'.\n"
     );
-    if ( $config->write( $config_file ) ) {
+    if ( $config->write( $config_file, "utf8" ) ) {
         return $config->{_};
     }
     else {
@@ -483,7 +483,7 @@ sub _normalize_id_file {
 
 sub _open_config_file {
     my $config_file = _get_config_file();
-    my $config = Config::Tiny->read( $config_file )
+    my $config = Config::Tiny->read( $config_file, "utf8" )
         or $CPAN::Frontend->mywarn("CPAN::Reporter: couldn't read configuration file " .
                 "'$config_file': \n" . Config::Tiny->errstr() . "\n");
     return $config;
@@ -671,7 +671,7 @@ CPAN::Reporter::Config - Config file options for CPAN::Reporter
 
 =head1 VERSION
 
-version 1.2018
+version 1.2020
 
 =head1 SYNOPSIS
 
@@ -987,7 +987,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2006 by David Golden.
+This software is Copyright (c) 2023 by David Golden.
 
 This is free software, licensed under:
 
